@@ -19,7 +19,7 @@ def main(argv=None):
     parser.add_argument('--codecs', help='print supported codecs',
                         action='store_true', default=False)
     parser.add_argument('--version', action='version',
-                        version='fastavro {0}'.format(avro.__version__))
+                        version='fastavro %s' % avro.__version__)
     parser.add_argument('-p', '--pretty', help='pretty print json',
                         action='store_true', default=False)
     args = parser.parse_args(argv[1:])
@@ -37,13 +37,12 @@ def main(argv=None):
             try:
                 fo = open(filename, 'rb')
             except IOError as e:
-                raise SystemExit(
-                    'error: cannot open {0} - {1}'.format(filename, e))
+                raise SystemExit('error: cannot open %s - %s' % (filename, e))
 
         try:
             reader = avro.reader(fo)
         except ValueError as e:
-            raise SystemExit('error: {0}'.format(e))
+            raise SystemExit('error: %s' % e)
 
         if args.schema:
             json_dump(reader.schema, True)
